@@ -23,9 +23,12 @@ if (TYPE_CHECKING):
 
 
 try:
-	import pkg_resources
-	package_version = pkg_resources.get_distribution(__package__).version
-except pkg_resources.DistributionNotFound:
+	try:
+		from importlib.metadata import version
+	except ModuleNotFoundError:  # python < 3.8 use polyfill
+		from importlib_metadata import version  # type: ignore
+	package_version = version(__package__)
+except Exception:
 	package_version = 'unknown'
 
 
